# API reference

```{toctree}
:maxdepth: 2
:hidden:

api-public
api-modules
api-baseclasses
```

## Modules

```{eval-rst}

.. autosummary::

    cmomy
    cmomy.reduction
    cmomy.resample
    cmomy.random
    cmomy.compile
    cmomy.core.typing
    cmomy.confidence_interval
    cmomy.rolling
    cmomy.utils
```
